@@ -1687,6 +1687,12 @@ static double peek(char *dest) /* peek into internals */
     return LINES;
   } else if (!strcmp(dest, "screenwidth")) {
     return COLS;
+  } else if (!strcmp(dest, "displaywidth")) {
+    if (displaywidth == 0) determine_display_size();
+    return displaywidth;
+  } else if (!strcmp(dest, "displayheight")) {
+    if (displayheight == 0) determine_display_size();
+    return displayheight;
   } else if (!strcmp(dest, "argument") || !strcmp(dest, "arguments")) {
     return yabargc;
   } else if (!strcmp(dest, "version")) {
